use adw::gdk::Display;

use gtk::{
    style_context_add_provider_for_display, CssProvider, STYLE_PROVIDER_PRIORITY_APPLICATION, Settings
};

pub fn load_css(settings: &Settings) {
    let style_provider = CssProvider::new();

    let theme = settings.gtk_theme_name();

    match theme {
        Some(theme_type) => {
            let theme_string = theme_type.to_string();
            if theme_string.contains("dark") || settings.is_gtk_application_prefer_dark_theme() {
                style_provider.load_from_string(include_str!("base_dark.css"));
            } else {
                style_provider.load_from_string(include_str!("base_light.css"));
            }
        },
        None => eprintln!("Theme hasn't been determined."),
    }

    style_context_add_provider_for_display(
        &Display::default().expect("Could not connect to a display"),
        &style_provider,
        STYLE_PROVIDER_PRIORITY_APPLICATION,
    );
}
